=======
Credits
=======

Development Lead
----------------

* Éric Dupuis <dupuis.eric@ouranos.ca> `@coxipi <https://github.com/coxipi>`_

Co-Developers
-------------

* Pascal Bourgault <bourgault.pascal@ouranos.ca> `@aulemahal <https://github.com/aulemahal>`_
* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_

Contributors [*]_
-----------------

* Abel Aoun <aoun.abel@gmail.com> `@bzah <https://github.com/bzah>`_
* Alexis Beaupré-Laperrière `@Beauprel <https://github.com/Beauprel>`_
* Marco Braun <Braun.Marco@ouranos.ca> `@vindelico <https://github.com/vindelico>`_
* Sarah Gammon `@SarahG-579462 <https://github.com/SarahG-579462>`_
* Jan Haacker `@j-haacker <https://github.com/j-haacker>`_
* Sascha Hofmann <sascha.hofmann@lobelia.earth> `@saschahofmann <https://github.com/saschahofmann>`_
* David Huard <huard.david@ouranos.ca> `@huard <https://github.com/huard>`_
* Adrien Lamarche `@LamAdr <https://github.com/LamAdr>`_
* Juliette Lavoie <lavoie.juliette@ouranos.ca> `@juliettelavoie <https://github.com/juliettelavoie>`_
* Gabriel Rondeau-Genesse <rondeau-genesse.gabriel@ouranos.ca> `@RondeauG <https://github.com/RondeauG>`_
* Philippe Roy `@Balinus <https://github.com/Balinus>`_

.. [*] The contributors list was ported from the `xclim` project. Some names might not correspond to any commit in the current repository.
